pub struct Npy<'a> { /* private fields */ }Expand description
memory view over a buffer in npy format
Implementations
Sourceimpl<'a> Npy<'a>
impl<'a> Npy<'a>
Sourcepub fn is_aligned(&self) -> bool
pub fn is_aligned(&self) -> bool
checks if the memory buffer is aligned, in which case the data can be referenced in-place
Sourcepub fn as_aligned_ref<T: FromNpy>(&self) -> MatRef<'_, T>
pub fn as_aligned_ref<T: FromNpy>(&self) -> MatRef<'_, T>
if the memory buffer is aligned, and the provided type matches the one stored in the buffer, returns a matrix view over the data